@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -94,9 +94,9 @@ void FilterBalsa::importMails(const QString &maildir)
     }
     setMailDir(maildir);
     /**
-    * If the user only select homedir no import needed because
-    * there should be no files and we surely import wrong files.
-    */
+     * If the user only select homedir no import needed because
+     * there should be no files and we surely import wrong files.
+     */
     if (mailDir() == QDir::homePath() || mailDir() == (QDir::homePath() + QLatin1Char('/'))) {
         filterInfo()->addErrorLogEntry(i18n("No files found for import."));
     } else {
@@ -158,20 +158,14 @@ void FilterBalsa::importFiles(const QString &dirName)
             return;
         }
         QString temp_mailfile = *mailFile;
-        if (!(temp_mailfile.endsWith(QLatin1String(".db"))
-              || temp_mailfile.endsWith(QLatin1String(".cmeta"))
-              || temp_mailfile.endsWith(QLatin1String(".ev-summary"))
-              || temp_mailfile.endsWith(QLatin1String(".ibex.index"))
+        if (!(temp_mailfile.endsWith(QLatin1String(".db")) || temp_mailfile.endsWith(QLatin1String(".cmeta"))
+              || temp_mailfile.endsWith(QLatin1String(".ev-summary")) || temp_mailfile.endsWith(QLatin1String(".ibex.index"))
               || temp_mailfile.endsWith(QLatin1String(".ibex.index.data")))) {
             if (!generatedPath) {
                 _path = i18nc("define folder name where we import evolution mails", "Evolution-Import");
                 QString _tmp = dir.filePath(*mailFile);
                 _tmp.remove(mailDir(), Qt::CaseSensitive);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                QStringList subFList = _tmp.split(QLatin1Char('/'), QString::SkipEmptyParts);
-#else
                 QStringList subFList = _tmp.split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#endif
                 QStringList::ConstIterator end(subFList.end());
                 for (QStringList::ConstIterator it = subFList.constBegin(); it != end; ++it) {
                     QString _cat = *it;
@@ -179,7 +173,7 @@ void FilterBalsa::importFiles(const QString &dirName)
                         if (_cat.startsWith(QLatin1Char('.'))) {
                             _cat.remove(0, 1);
                         }
-                        //Evolution store inbox as "."
+                        // Evolution store inbox as "."
                         if (_cat.startsWith(QLatin1Char('.'))) {
                             _cat.replace(0, 1, QStringLiteral("Inbox/"));
                         }
@@ -217,7 +211,7 @@ MailImporter::MessageStatus FilterBalsa::statusFromFile(const QString &filename)
             status.setRead(true);
         }
         if (statusStr.contains(QLatin1Char('F'))) {
-            //TODO
+            // TODO
         }
         if (statusStr.contains(QLatin1Char('R'))) {
             status.setReplied(true);
